@@ -1,5 +1,5 @@
 /* Return build ID information for a module.
-   Copyright (C) 2007, 2008, 2009 Red Hat, Inc.
+   Copyright (C) 2007-2010 Red Hat, Inc.
    This file is part of Red Hat elfutils.
 
    Red Hat elfutils is free software; you can redistribute it and/or modify
@@ -97,6 +97,7 @@ int
 internal_function
 __libdwfl_find_build_id (Dwfl_Module *mod, bool set, Elf *elf)
 {
+  size_t shstrndx = SHN_UNDEF;
   int result = 0;
 
   Elf_Scn *scn = elf_nextscn (elf, NULL);
@@ -106,12 +107,14 @@ __libdwfl_find_build_id (Dwfl_Module *mod, bool set, Elf *elf)
       /* No sections, have to look for phdrs.  */
       GElf_Ehdr ehdr_mem;
       GElf_Ehdr *ehdr = gelf_getehdr (elf, &ehdr_mem);
-      if (unlikely (ehdr == NULL))
+      size_t phnum;
+      if (unlikely (ehdr == NULL)
+	  || unlikely (elf_getphdrnum (elf, &phnum) != 0))
 	{
 	  __libdwfl_seterrno (DWFL_E_LIBELF);
 	  return -1;
 	}
-      for (uint_fast16_t i = 0; result == 0 && i < ehdr_mem.e_phnum; ++i)
+      for (size_t i = 0; result == 0 && i < phnum; ++i)
 	{
 	  GElf_Phdr phdr_mem;
 	  GElf_Phdr *phdr = gelf_getphdr (elf, i, &phdr_mem);
@@ -132,11 +135,13 @@ __libdwfl_find_build_id (Dwfl_Module *mod, bool set, Elf *elf)
 	if (likely (shdr != NULL) && shdr->sh_type == SHT_NOTE)
 	  {
 	    /* Determine the right sh_addr in this module.  */
-	    size_t shstrndx = SHN_UNDEF;
 	    GElf_Addr vaddr = 0;
-	    if (!(shdr->sh_flags & SHF_ALLOC)
-		|| __libdwfl_relocate_value (mod, elf, &shstrndx,
-					     elf_ndxscn (scn), &vaddr))
+	    if (!(shdr->sh_flags & SHF_ALLOC))
+	      vaddr = NO_VADDR;
+	    else if (mod->e_type != ET_REL)
+	      vaddr = shdr->sh_addr + mod->main.bias;
+	    else if (__libdwfl_relocate_value (mod, elf, &shstrndx,
+					       elf_ndxscn (scn), &vaddr))
 	      vaddr = NO_VADDR;
 	    result = check_notes (mod, set, elf_getdata (scn, NULL), vaddr);
 	  }
@@ -147,8 +152,8 @@ __libdwfl_find_build_id (Dwfl_Module *mod, bool set, Elf *elf)
 }
 
 int
-__dwfl_module_build_id (Dwfl_Module *mod,
-			const unsigned char **bits, GElf_Addr *vaddr)
+dwfl_module_build_id (Dwfl_Module *mod,
+		      const unsigned char **bits, GElf_Addr *vaddr)
 {
   if (mod == NULL)
     return -1;
@@ -171,19 +176,20 @@ __dwfl_module_build_id (Dwfl_Module *mod,
   *vaddr = mod->build_id_vaddr;
   return mod->build_id_len;
 }
-extern __typeof__ (dwfl_module_build_id) INTUSE(dwfl_module_build_id)
-     __attribute__ ((alias ("__dwfl_module_build_id")));
-asm (".symver "
-     "__dwfl_module_build_id, dwfl_module_build_id@@ELFUTILS_0.138");
+INTDEF (dwfl_module_build_id)
+NEW_VERSION (dwfl_module_build_id, ELFUTILS_0.138)
+
+#ifdef SHARED
+COMPAT_VERSION (dwfl_module_build_id, ELFUTILS_0.130, vaddr_at_end)
 
 int
-_BUG_COMPAT_dwfl_module_build_id (Dwfl_Module *mod,
-				  const unsigned char **bits, GElf_Addr *vaddr)
+_compat_vaddr_at_end_dwfl_module_build_id (Dwfl_Module *mod,
+					   const unsigned char **bits,
+					   GElf_Addr *vaddr)
 {
   int result = INTUSE(dwfl_module_build_id) (mod, bits, vaddr);
   if (result > 0)
     *vaddr += (result + 3) & -4;
   return result;
 }
-asm (".symver "
-     "_BUG_COMPAT_dwfl_module_build_id, dwfl_module_build_id@ELFUTILS_0.130");
+#endif
